==> seedsui-react-5.8.54.tgz: package/lib/Map/pages/MapMarkers/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import React, { useRef, forwardRef } from 'react';
import locale from "./../../../locale";
import IconUtil from "./../../utils/IconUtil";
import MapContainer from "./../../components/MapContainer";
import ZoomControl from "./../../components/ZoomControl";
import Markers from "./../../components/Markers";
import Result from "./../../components/Result";

// 地图标注
function MapMarkers(_ref, ref) {
  var points = _ref.points,
    icon = _ref.icon,
    onMarkerClick = _ref.onMarkerClick,
    ZoomControlProps = _ref.ZoomControlProps,
    children = _ref.children;
  // 放大缩小
  var zoomRef = useRef(null);
  if (!Array.isArray(points) || !points.length) return /*#__PURE__*/React.createElement(Result, {
    title: "".concat(locale('请传入参数', 'SeedsUI_need_pass_parameter_error'), "points")
  });
  return /*#__PURE__*/React.createElement(MapContainer
  // api
  , {
    ref: ref,
    center: points,
    zoom: 14
    // 基准路径
    ,
    iconOptions: {
      imagePath: 'https://res.waiqin365.com/d/seedsui/leaflet/images/'
    }
  }, /*#__PURE__*/React.createElement(Markers, {
    points: points.map(function (point) {
      return _objectSpread(_objectSpread({}, point), {}, {
        icon: IconUtil.getIcon((point === null || point === void 0 ? void 0 : point.icon) || icon)
      });
    }),
    onClick: onMarkerClick
  }), /*#__PURE__*/React.createElement(ZoomControl, _extends({
    ref: zoomRef,
    style: {
      bottom: '20px'
    }
  }, ZoomControlProps)), children);
}
export default /*#__PURE__*/forwardRef(MapMarkers);

==> seedsui-react-5.8.59.tgz: package/lib/Map/pages/MapMarkers/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import React, { forwardRef } from 'react';

// 内库使用
import locale from "./../../../locale";

// 测试使用
// import { locale } from 'seedsui-react'

import IconUtil from "./../../utils/IconUtil";
import MapContainer from "./../../components/MapContainer";
import ZoomControl from "./../../components/ZoomControl";
import Markers from "./../../components/Markers";
import Result from "./../../components/Result";

// 地图标注
function MapMarkers(_ref, ref) {
  var points = _ref.points,
    icon = _ref.icon,
    getAddress = _ref.getAddress,
    getLocation = _ref.getLocation,
    queryNearby = _ref.queryNearby,
    onMarkerClick = _ref.onMarkerClick,
    _onLoad = _ref.onLoad,
    onMarkerEnd = _ref.onMarkerEnd,
    ZoomControlProps = _ref.ZoomControlProps,
    children = _ref.children;
  if (!Array.isArray(points) || !points.length) return /*#__PURE__*/React.createElement(Result, {
    title: "".concat(locale('请传入参数', 'SeedsUI_need_pass_parameter_error'), "points")
  });
  return /*#__PURE__*/React.createElement(MapContainer
  // api
  , {
    ref: ref,
    center: points,
    zoom: 14
    // 基准路径
    ,
    iconOptions: {
      imagePath: 'https://res.waiqin365.com/d/seedsui/leaflet/images/'
    },
    onLoad: function onLoad(map) {
      // value没值时，开启自动定位，则先定位
      if (typeof map === 'string') return;
      _onLoad && _onLoad(map);
    }
    // 自定义获取地址和定位
    ,
    getAddress: getAddress,
    getLocation: getLocation,
    queryNearby: queryNearby
  }, /*#__PURE__*/React.createElement(Markers, {
    points: points.map(function (point) {
      return _objectSpread(_objectSpread({}, point), {}, {
        icon: IconUtil.getIcon((point === null || point === void 0 ? void 0 : point.icon) || icon)
      });
    }),
    onClick: onMarkerClick,
    onMarkerEnd: onMarkerEnd
  }), /*#__PURE__*/React.createElement(ZoomControl, _extends({
    style: {
      bottom: '20px'
    }
  }, ZoomControlProps)), children);
}
export default /*#__PURE__*/forwardRef(MapMarkers);
